# Wizard's Toolkit #
This Docker environment includes database, PHP8, and MySQL8 or PostgreSQL.

* PHP 8.1 using PDO
* MySQL "latest" version
* PostgreSQL "latest" version for the database
* Nginx and Alpine for fast and lightweight OS

This makes for an excellent developer environment using Docker on a Mac or Windows PC with WSL 2.

## Prerequisites ##

1. Only if you are using Windows do you need to have WSL2 installed and configured with Ubuntu 20.04LTS.  Note: it works on Mac without WSL2.
2. Install latest Docker Desktop for your platform from: https://www.docker.com/get-started/
3. Set up an account with Docker Hub: https://hub.docker.com/ - it is free and essential.
4. Start Docker Desktop and sign in to Docker Hub using the **Sign in** button at the top right
5. Configure settings in Docker Desktop (click gear "Settings" to access)
	- Start Docker Desktop when you log in (optional)
	- Use Docker Compose V2
**Resources**
WSL INTEGRATION
	- (Windows only) - Enable integration with my default WSL distro
	- (Windows only) - Enable integration with any addition WSL distros

6. Check out latest version from BitBucket.org

7. Add the following entries to your host file:
```
127.0.0.1   dev.wtk.com
```
On Mac you can do this by running in Terminal the following:
```
sudo nano /etc/hosts
```

**Note:**
You must not be running any web server or other software on your machine which runs on
port 80 and/or 443 or the containers will not work.  For example use MAMP or Docker
but not both for your Wizard's Toolkit environment.

## SQL Offerings ##

Wizard's Toolkit works equally well with MySQL and PostgreSQL.  It has been tested
and verified with both older versions of MySQL and the most recent versions.  It
also works well with Percona database.

The first thing you should do is decide whether you want to use MySQL or PostgreSQL
then delete the other from the docker-compose.yml so you do not install into your
Docker a database you will not be using.

For example, if you will be using MySQL you can delete the **wtk_db_pg** service.
If you will be using PostgreSQL then you can delete the **wtk_db_mysql** service
and you should change **phpMySQL.env** to: **phpPG.env** which has environment
variables for PostgreSQL database access.

For local development the database is in the /Mounts folder.
If you are using MySQL then your data will be in /Mounts/mydata.
If you are using PostgreSQL then your data will be in /Mounts/pgdata.

The SQL Scripts to create the core Wizard's Toolkit database are in SqlSetup.
For MySQL you will need to run these scripts in the /SQL/mySQL/SetupDB folder which
you can do with this:
```
./SETUP_MYSQL.sh
```

Note that PostgreSQL will run it's setup scripts automatically as part of the
Docker setup if the DB does not exist.

The database setup (either way) will create the tables, functions, procedures,
triggers and insert initial core data.


## Getting Started ##

1. In your MacOS/WSL2 Ubuntu command line terminal change into the directory containing WTKdocker

2. Build Docker containers:
```
./WTK.sh
```
This may take a 10 to 50 seconds the first time you do it depending on your internet speed.

If you receive a failure like:
```
failed to solve: rpc error: code = Unknown
desc = failed to solve with frontend dockerfile.v0:
failed to create LLB definition: dockerfile parse error line 1: unknown instruction:
```
Use this script then retry:
```
export DOCKER_BUILDKIT=0
```

The very first time you do this, MySQL and/or PostgreSQL will need to create a
blank set of core SQL files in ./Mounts/ so it may be a minute before you can
get into the database using the step below.

In DockerDesktop you can click to see what processes are running in your database and
use that to determine when it is ready.

3. To verify MySQL database is running ok, in terminal run:
```
./MYSQL.sh
show databases;
```
If you are using MySQL and database has not already been created, run:
```
./SETUP_MYSQL.sh
```
.. to add tables and data necessary for new framework and database.  If you receive
errors (not just password warnings), something went wrong and it's best to
delete entire MySQL /Mounts/mydata folder and restart.  After running SETUP_MYSQL.sh
verify using:
```
./MYSQL.sh
USE wiztools;
show tables;
```

### First Time Website Access ###

Below links assume you set your hosts file to use dev.wtk.com.  Change links to 127.0.0.1
if you skipped that step.

First access this web page to verify Docker configuration is working properly.  From this link you can verify SQL connectivity, environment variables, and email functionality.
There is also a link to set your admin password.

http://dev.wtk.com/devUtils/testWTK.php

To set the password for the default login:
http://dev.wtk.com/wtk/passwordReset.php?u=needToSet

Then go to main website and login using email address of: admin@email.com
http://dev.wtk.com

When you want to modify the main page for your website, edit /app/public/index.php

## PostgreSQL Notes and Commands ##

If you do not already have a PostgreSQL client,
download free GUI Client to access: https://dbeaver.io/

Create a PostgreSQL connection
```
Database:               pgwiztools
Change username to:     wizdba
and password to:        (find in docker-compose.yml)
```
Make sure your Mac has not started a Postgres Server which you can see in the top-bar.  If it has, quit it.

### Database Reset ###

If you want to wipe out your current DB and start with a fresh database, simply
follow these steps in Terminal:

```
./STOP_CONTAINERS.sh
In Finder delete /Mounts/pgdata folder or /Mounts/mydata
./START_CONTAINERS.sh	which will rebuild SQL system files and database
./SETUP_MYSQL.sh    if you are using MySQL and not PostgreSQL
```
**Note:** If you are using PostgreSQL you can skip the SETUP_MYSQL.sh step

## Useful Commands to run in Terminal ##
```
./STOP_CONTAINERS.sh
```
```
./REBUILD_CONTAINERS.sh
```
```
./RESTART_WEBSITE.sh
```

To remove **ALL** containers
```
docker rm -f $(docker ps -a -q)
```
To remove **ALL** images
```
docker image rm $(docker image ls -q)
```
To get the IMAGE_ID's
```
docker image ls
```
To remove single image
```
docker image rm {IMAGE_ID}
```
To show all containers, running and stopped
```
docker ps -a
```
To enter a shell on the specified container
```
docker exec -it {IMAGE_ID} sh
```
To make new .sh file executable
```
chmod a+x foo.sh
```

### Miscellaneous Information ###

Most likely you will never need anything below this point.

#### To access Postgres DB in terminal ####

```
docker exec -it db_postgresql sh
psql -h localhost -p 5432 -d pgwiztools -U wizdba
```
... then must manually enter password (find in docker-compose.yml)

### Useful Links ###

Excellent Documentation:
https://www.howtogeek.com/devops/how-to-deploy-postgresql-as-a-docker-container/

https://hevodata.com/learn/docker-postgresql/

https://postgresapp.com/

https://www.databasestar.com/mysql-output-file/

https://www.sitepoint.com/docker-php-development-environment/

https://marcit.eu/en/2021/04/28/dockerize-webserver-nginx-php8/

https://stackoverflow.com/questions/37526509/how-to-install-pdo-driver-in-php-docker-image

https://turreta.com/2019/09/09/docker-compose-yml-for-mysql/
